Learn R Programming

tintin (version 0.2)

tintin-package: tintin: Tintin Palette Generator

Description

Palettes generated from Tintin covers. There is one palette per cover, with a total of 24 palettes of 5 colours each. Includes functions to interpolate colors in order to create more colors based on the provided palettes.The data is based on Cyr, et al. (2004) tools:::Rd_expr_doi("10.1503/cmaj.1041405") and Wikipedia https://en.wikipedia.org/wiki/The_Adventures_of_Tintin.

Arguments

Author

Maintainer: Mauricio Vargas Sepulveda m.sepulveda@mail.utoronto.ca (ORCID)