Learn R Programming

tintin (version 0.2)

tintin_head_trauma: Tintin Head Trauma

Description

Neurological traumas sustained by the subject (by book title)

Usage

tintin_head_trauma

Arguments

Format

A data frame with 50 rows and 4 variables

Details

year

Release year of the comic, first occurrence was used for titles with a b&w and colour edition

book_title

English title of the books

page

Page number where the traumas happen

cause_of_injury

What causes the trauma (i.e., explosion)

loss_of_consciousness_length

Loss of consciousness length measured by the number of cartoon frames before subject returns to normal activity.

loss_of_consciousness_severity

Loss of consciousness severity measured by the number of objects revolving above Tintin's head

Examples

Run this code
tintin_head_trauma

Run the code above in your browser using DataLab